#! python
# -*- coding: utf-8 -*-


"""Module for pulse sequence related classes and functions.

Authors:
    * Victor Hugo de Mello Pessoa <victor.pessoa@usp.br>
    * Daniel Cosmo Pizetta <daniel.pizetta@usp.br>

Since:
    2017/07/01

"""

import logging

import numpy as np
import pyqtgraph.parametertree as pt

from mrsprint.system import gradient, rf

_logger = logging.getLogger(__name__)


class Sequence(pt.parameterTypes.GroupParameter):
    """Class that represents a sequence for magnetic resonance systems."""

    def __init__(self, settings, **opts):
        opts['name'] = 'Sequence'
        opts['type'] = 'bool'
        opts['value'] = True
        pt.parameterTypes.GroupParameter.__init__(self, **opts)

        self.settings = settings
        dt = settings.simulator_group.timeResolution.value()
        self.__rf = rf.rfDelay(dt)
        self.__gradient = gradient.gradientDelay(dt)

    def setRF(self, rf):
        """Properly sets the rf stream signal."""
        for rep_num, events in rf:
            for _ in np.arange(0, rep_num):
                for event in events:
                    self.__rf = np.append(self.__rf, event)

    def getRF(self):
        """Return the entire rf."""
        return self.__rf

    def setGradient(self, gradient):
        """Properly sets the gradient."""
        for rep_num, events in gradient:
            for _ in np.arange(0, rep_num):
                for event in events:
                    self.__gradient = np.append(self.__gradient, event)

    def getGradient(self):
        """Return the entire gradient."""
        rf_shape = self.__rf.shape
        gradient_size = self.__gradient.size

        grad_zero = np.zeros(3 * (rf_shape[0])).reshape(3, rf_shape[0])

        if 3 * rf_shape[0] != gradient_size:
            if gradient_size <= 3:
                self.__gradient = grad_zero
            else:
                raise ValueError("RF and Gradient must have the same temporal size!")
        return self.__gradient


class CPMGSequence(Sequence):
    """Generates a CPMG sequence."""

    def __init__(self):
        Sequence.__init__(self)
        # sequence specific parameters

        self.numberOfCicles = self.addChild({'name': 'Number of Cicles', 'type': 'int', 'value': 3})
        self.te = self.addChild({'name': 'Time to Echo', 'type': 'float', 'value': 0.02, 'suffix': 's', 'siPrefix': True})
        self.dtr = self.addChild({'name': 'Delay TR', 'type': 'float', 'value': 0.02, 'suffix': 's', 'siPrefix': True})

        # pulse of 90 degrees in x
        rf_90_x = rf.squareRFPulse(flip_angle=90, phase=0)
        t_half_rf_90 = rf.rfDuration(rf_90_x) / 2.
        # pulse of 180 degrees in y
        rf_180_y = rf.squareRFPulse(flip_angle=180, phase=90)
        t_half_rf_180 = rf.rfDuration(rf_180_y) / 2.

        # delay bewteen pulse 90x and 180y  = te/2 between pulse centers
        d_90_180 = rf.rfDelay(-t_half_rf_90 + self.te.value() / 2. - t_half_rf_180)
        # delay bewteen pulse 180y and 180y  = te between pulse centers
        d_180_180 = rf.rfDelay(-t_half_rf_180 + self.te.value() - t_half_rf_180)
        # delay repetition time before reinitiates
        d_tr = rf.rfDelay(self.dtr.value())

        # rf for CPMG
        self.setRF([(1, [rf_90_x, d_90_180]),
                    (self.numberOfCicles.value(), [-rf_180_y, d_180_180, rf_180_y, d_180_180]),
                    (1, [d_tr])])


class GradientEchoSequence(Sequence):
    """Generate a Gradient Echo sequence."""

    def __init__(self):
        Sequence.__init__(self)
        # sequence specific parameters
        self.a90 = self.addChild({'name': 'Delay After RF', 'type': 'float', 'value': 0.01, 'suffix': 's', 'siPrefix': True})
        self.te = self.addChild({'name': 'Time to Echo', 'type': 'float', 'value': 0.02, 'suffix': 's', 'siPrefix': True})
        self.dtr = self.addChild({'name': 'Delay TR', 'type': 'float', 'value': 0.01, 'suffix': 's', 'siPrefix': True})

        # first event, excitation
        rf_90_x = rf.squareRFPulse(flip_angle=90, phase=0)
        t_rf_90 = rf.rfDuration(rf_90_x)
        d_gr_90 = gradient.gradientDelay(t_rf_90)

        # second event, a delay
        d_rf_a90 = rf.rfDelay(self.dbgr.value())
        d_gr_a90 = gradient.gradientDelay(self.dbgr.value())

        # third event, dephasing
        d_rf_deph = rf.rfDelay()
        gr_deph = gradient.SquareGradient()

        # fourth event, read
        d_rf_read = rf.rfDelay()
        gr_read = gradient.SquareGradient()

        # fifty event, a delay
        d_rf_tr = rf.rfDelay(self.dtr.value())
        d_gr_tr = gradient.gradientDelay(self.dtr.value())

        self.setRF([(1, [rf_90_x, d_rf_a90, d_rf_deph, d_rf_read, d_rf_tr])])
        self.setGradient([(1, [d_gr_90, d_gr_a90, gr_deph, gr_read, d_gr_tr])])



#! python
# -*- coding: utf-8 -*-

"""Package for simulator related classes and objects.

Authors:
    * Daniel Cosmo Pizetta <daniel.pizetta@usp.br>

Since:
    2018/06/07

Todo:
    Maybe remove old_plot module.

"""


import logging

import numpy as np

_logger = logging.getLogger(__name__)


def reduce_magnetization_in_frequency(mx, my, mz, freq_shift, fsa_size):
    """Reduces the magnetization vector by summing frequency components.

    Args:
        mx (np.array): Array of magnetization x without reduction in frequency.
        my (np.array): Array of magnetization y without reduction in frequency.
        mz (np.array): Array of magnetization z without reduction in frequency.
        freq_shift (np.array):  Array of frequency shift.
        fsa_size (int): Size of array of frequency shift.

    Returns:
        tuple: (mx, my, mz) arrays of magnetization reduced

    Todo:
        Shape size different of 2.
        Better solution for freq_shift array.
        Set physical unit for each args.

    """
    fsa_size = fsa_size - 1
    fsa_size_half = int(fsa_size / 2)

    if len(mx.shape) >= 2:
        mx_neg = np.sum(mx[:fsa_size_half], axis=0)
        mx_pos = np.sum(mx[fsa_size_half + 1:], axis=0)
        mx_f = mx_neg + mx_pos + mx[fsa_size_half]
    else:
        mx_f = mx

    if len(my.shape) >= 2:
        my_neg = np.sum(my[:fsa_size_half], axis=0)
        my_pos = np.sum(my[fsa_size_half + 1:], axis=0)
        my_f = my_neg + my_pos + my[fsa_size_half]
    else:
        my_f = my

    if len(mz.shape) >= 2:
        mz_neg = np.sum(mz[:fsa_size_half], axis=0)
        mz_pos = np.sum(mz[fsa_size_half + 1:], axis=0)
        mz_f = mz_neg + mz_pos + mz[fsa_size_half]
    else:
        mz_f = mz

    max_global = np.max((np.max(mx_f), np.max(my_f), np.max(mz_f)))

    return mx_f / max_global, my_f / max_global, mz_f / max_global


def reduce_magnetization_in_position(mx, my, mz, position, freq_shift):
    """Reduces the magnetization vector by summing position components.

    Args:
        mx (np.array): Array of x magnetization without reduction in frequency.
        my (np.array): Array of y magnetization without reduction in frequency.
        mz (np.array): Array of z magnetization without reduction in frequency.
        position (np.array): Array of positions.
        freq_shift (np.array): Array of frequency shift.

    Returns:
        tuple: (mx, my, mz) arrays of magnetization reduced.

    Todo:
        Test shape size different of 2.
        Set physical unit for each args.

    """
    _logger.debug("Shapes for mxyz {}, freq_shift {} and position {}".format(mx.shape,
                                                                             freq_shift.shape,
                                                                             position.shape))

    mxf, myf, mzf = reduce_magnetization_in_frequency(mx, my, mz, freq_shift, freq_shift.size)
    mxf, myf, mzf = reduce_magnetization_in_frequency(mxf, myf, mzf, position, position.shape[1])

    return mxf, myf, mzf


def create_positions(size=(1, 1, 1), step=(1., 1., 1.), offset=(0., 0., 0.), dtype=np.float32):
    """Creates array of positions.

    Args:
        size (tuple(int)): Size in x, y and z. The minimum number is one for each axis.
        step (tuple(float)): Step for each axis.
        offset (tuple(float)): Offset for each axis. If zero, the final vector begins in
            zero and ends in size plus offset.

    Returns:
        np.array: Position array in this format [[gr_x_plotx gr_y_plotx gr_z_plotx ...]
            [gr_x_ploty gr_y_ploty gr_z_ploty ...][gr_x_plotz gr_y_plotz gr_z_plotz ...]],
            where p is the number of position (from offset to size plus offset).

    Todo:
        Set physical unit for each args.

    """
    if np.min(step) <= 0.:
        raise ValueError("Step values must be greater then zero")

    size_scaled = size[0] / step[0], size[1] / step[1], size[2] / step[2]

    xposf = np.array([])
    yposf = np.array([])
    zposf = np.array([])

    if (size_scaled[0] >= 1. and size_scaled[1] >= 1. and size_scaled[2] >= 1.):
        nelements = np.prod(np.array(size_scaled))
        xpos = np.arange(offset[0], size[0] + offset[0], step[0])
        ypos = np.arange(offset[1], size[1] + offset[1], step[1])
        zpos = np.arange(offset[2], size[2] + offset[2], step[2])

        for element in np.arange(0, nelements):
            xposf = np.append(xposf, xpos[int(element % xpos.size)])
            yposf = np.append(yposf, ypos[int((element / xpos.size) % ypos.size)])
            zposf = np.append(zposf, zpos[int((element / (xpos.size * ypos.size)) % zpos.size)])
    else:
        raise ValueError("Step values must be equal or greater than size values.")

    posf = np.array([xposf, yposf, zposf])
    return posf


def frequency_shift(freq_shift, freq_step=1., offset=0., symetric=True, dtype=np.float32):
    """Generates an array of frequency shift, from -frequency_shift to +frequency_shift, between offset.

    Args:
        freq_shift (float [Hz]): Maximum frequency to shift.
        freq_step (float [Hz]): Spacing between values.
        offset (float [Hz]): Offset frequency.
        symetric (bool): If true, generates the array between offset (-maximum shift,
            maximum shift), otherwise from offset to maximum frequency. Default is True.
        dtype (np.dtype): Data type for the array. Default is np.float32.

    Returns:
        np.array [Hz]: Array of frequency shift value.

    Todo:
        Use the key symetric for something.

    """
    f_neg = np.arange(-freq_step, -freq_shift, -freq_step, dtype=dtype)[::-1]
    f_pos = np.arange(freq_step, freq_shift, freq_step, dtype=dtype)
    f_zero = np.arange(0., 1., dtype=dtype)
    frequency_shift = np.concatenate((f_neg, f_zero, f_pos)) + offset

    return frequency_shift


def calculate_t2_star(t2, freq_shift):
    """Returns the value for t2*, considering the range of frequencies.

    Args:
        t2 (float [s]): T2 value in seconds.
        freq_shift (float [Hz]): Frequency shift from resonance - symetric 
            between zero (in resonance).

    Returns:
        float [s]: T2 star value.

    Todo:
        Confirm if it is the right way to calculate or if it has a weight function for t2star
        Pass freq_shift as a number?

    """
    shift = np.max(freq_shift) + np.abs(np.min(freq_shift))
    t2star = 1. / (1. / t2 + shift)
    return t2star


def transform_cart_to_pol(x, y):
    """Returns a transformed catesian vector into polar coordinates.

    Args:
        x (np.array): X coordinate.
        y (np.array): Y coordinate.

    Returns:
        tuple: (rho, phi) vectors formed by radial and angular coordinates.

    """
    rho = np.sqrt(x**2 + y**2)
    phi = np.arctan2(y, x)

    return (rho, phi)


def transform_pol_to_cart(rho, phi):
    """Returns a transformed polar vector into cartesian coordinates.

    Args:
        rho (np.array): Radial coordinate.
        phi (np.array): Angular coordinate.

    Returns:
        tuple: (x, y) vectors formed by x and y coordinates

    """
    x = rho * np.cos(phi)
    y = rho * np.sin(phi)

    return (x, y)



#! python
# -*- coding: utf-8 -*-

"""Package for GUI related classes and objects.

Authors:
    * Victor Hugo de Mello Pessoa <victor.pessoa@usp.br>
    * Daniel Cosmo Pizetta <daniel.pizetta@usp.br>

Since:
    2017/01/09

"""



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mw_mrsprint.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from pyqtgraph.Qt import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(1002, 1187)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setAutoFillBackground(True)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.gridLayout_4 = QtGui.QGridLayout(self.centralwidget)
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        MainWindow.setCentralWidget(self.centralwidget)
        self.toolBarSampleElement = QtGui.QToolBar(MainWindow)
        self.toolBarSampleElement.setStyleSheet(_fromUtf8(""))
        self.toolBarSampleElement.setIconSize(QtCore.QSize(42, 42))
        self.toolBarSampleElement.setObjectName(_fromUtf8("toolBarSampleElement"))
        MainWindow.addToolBar(QtCore.Qt.LeftToolBarArea, self.toolBarSampleElement)
        self.toolBar2DEditor = QtGui.QToolBar(MainWindow)
        self.toolBar2DEditor.setIconSize(QtCore.QSize(32, 32))
        self.toolBar2DEditor.setObjectName(_fromUtf8("toolBar2DEditor"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar2DEditor)
        self.toolBar3DViewCamera = QtGui.QToolBar(MainWindow)
        self.toolBar3DViewCamera.setIconSize(QtCore.QSize(32, 32))
        self.toolBar3DViewCamera.setObjectName(_fromUtf8("toolBar3DViewCamera"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar3DViewCamera)
        self.dockWidgetParameters = QtGui.QDockWidget(MainWindow)
        self.dockWidgetParameters.setMinimumSize(QtCore.QSize(200, 43))
        self.dockWidgetParameters.setObjectName(_fromUtf8("dockWidgetParameters"))
        self.dockWidgetContentsParameters = QtGui.QWidget()
        self.dockWidgetContentsParameters.setObjectName(_fromUtf8("dockWidgetContentsParameters"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.dockWidgetContentsParameters)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.dockWidgetParameters.setWidget(self.dockWidgetContentsParameters)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dockWidgetParameters)
        self.dockWidget2DEditorXY = QtGui.QDockWidget(MainWindow)
        self.dockWidget2DEditorXY.setFeatures(QtGui.QDockWidget.DockWidgetFloatable|QtGui.QDockWidget.DockWidgetMovable)
        self.dockWidget2DEditorXY.setObjectName(_fromUtf8("dockWidget2DEditorXY"))
        self.dockWidgetContents2DEditorXY = QtGui.QWidget()
        self.dockWidgetContents2DEditorXY.setObjectName(_fromUtf8("dockWidgetContents2DEditorXY"))
        self.gridLayout_5 = QtGui.QGridLayout(self.dockWidgetContents2DEditorXY)
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.spinBox2DEditorZIndex = QtGui.QSpinBox(self.dockWidgetContents2DEditorXY)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox2DEditorZIndex.sizePolicy().hasHeightForWidth())
        self.spinBox2DEditorZIndex.setSizePolicy(sizePolicy)
        self.spinBox2DEditorZIndex.setMinimum(0)
        self.spinBox2DEditorZIndex.setMaximum(999)
        self.spinBox2DEditorZIndex.setProperty("value", 0)
        self.spinBox2DEditorZIndex.setObjectName(_fromUtf8("spinBox2DEditorZIndex"))
        self.gridLayout_5.addWidget(self.spinBox2DEditorZIndex, 1, 1, 1, 1)
        self.label2DEditorZIndex = QtGui.QLabel(self.dockWidgetContents2DEditorXY)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label2DEditorZIndex.sizePolicy().hasHeightForWidth())
        self.label2DEditorZIndex.setSizePolicy(sizePolicy)
        self.label2DEditorZIndex.setAlignment(QtCore.Qt.AlignCenter)
        self.label2DEditorZIndex.setObjectName(_fromUtf8("label2DEditorZIndex"))
        self.gridLayout_5.addWidget(self.label2DEditorZIndex, 1, 0, 1, 1)
        self.horizontalSlider2DEditorZIndex = QtGui.QSlider(self.dockWidgetContents2DEditorXY)
        self.horizontalSlider2DEditorZIndex.setMinimum(0)
        self.horizontalSlider2DEditorZIndex.setMaximum(999)
        self.horizontalSlider2DEditorZIndex.setProperty("value", 0)
        self.horizontalSlider2DEditorZIndex.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider2DEditorZIndex.setTickPosition(QtGui.QSlider.NoTicks)
        self.horizontalSlider2DEditorZIndex.setObjectName(_fromUtf8("horizontalSlider2DEditorZIndex"))
        self.gridLayout_5.addWidget(self.horizontalSlider2DEditorZIndex, 1, 2, 1, 1)
        self.tableWidget2DEditorXY = QtGui.QTableWidget(self.dockWidgetContents2DEditorXY)
        self.tableWidget2DEditorXY.setObjectName(_fromUtf8("tableWidget2DEditorXY"))
        self.tableWidget2DEditorXY.setColumnCount(0)
        self.tableWidget2DEditorXY.setRowCount(0)
        self.gridLayout_5.addWidget(self.tableWidget2DEditorXY, 0, 0, 1, 3)
        self.dockWidget2DEditorXY.setWidget(self.dockWidgetContents2DEditorXY)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dockWidget2DEditorXY)
        self.menuBar = QtGui.QMenuBar(MainWindow)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 1002, 28))
        self.menuBar.setObjectName(_fromUtf8("menuBar"))
        self.menuFile = QtGui.QMenu(self.menuBar)
        self.menuFile.setObjectName(_fromUtf8("menuFile"))
        self.menuSampleElement = QtGui.QMenu(self.menuBar)
        self.menuSampleElement.setObjectName(_fromUtf8("menuSampleElement"))
        self.menuHelp = QtGui.QMenu(self.menuBar)
        self.menuHelp.setObjectName(_fromUtf8("menuHelp"))
        self.menuConfiguration = QtGui.QMenu(self.menuBar)
        self.menuConfiguration.setObjectName(_fromUtf8("menuConfiguration"))
        self.menu2DEditor = QtGui.QMenu(self.menuBar)
        self.menu2DEditor.setObjectName(_fromUtf8("menu2DEditor"))
        self.menu3DView = QtGui.QMenu(self.menuBar)
        self.menu3DView.setObjectName(_fromUtf8("menu3DView"))
        self.menuEdit = QtGui.QMenu(self.menuBar)
        self.menuEdit.setObjectName(_fromUtf8("menuEdit"))
        MainWindow.setMenuBar(self.menuBar)
        self.dockWidget2DEditorYZ = QtGui.QDockWidget(MainWindow)
        self.dockWidget2DEditorYZ.setFeatures(QtGui.QDockWidget.DockWidgetFloatable|QtGui.QDockWidget.DockWidgetMovable)
        self.dockWidget2DEditorYZ.setObjectName(_fromUtf8("dockWidget2DEditorYZ"))
        self.dockWidgetContents2DEditorYZ = QtGui.QWidget()
        self.dockWidgetContents2DEditorYZ.setObjectName(_fromUtf8("dockWidgetContents2DEditorYZ"))
        self.gridLayout_6 = QtGui.QGridLayout(self.dockWidgetContents2DEditorYZ)
        self.gridLayout_6.setObjectName(_fromUtf8("gridLayout_6"))
        self.label2DEditorXIndex = QtGui.QLabel(self.dockWidgetContents2DEditorYZ)
        self.label2DEditorXIndex.setObjectName(_fromUtf8("label2DEditorXIndex"))
        self.gridLayout_6.addWidget(self.label2DEditorXIndex, 1, 1, 1, 1)
        self.spinBox2DEditorXIndex = QtGui.QSpinBox(self.dockWidgetContents2DEditorYZ)
        self.spinBox2DEditorXIndex.setMinimum(0)
        self.spinBox2DEditorXIndex.setMaximum(999)
        self.spinBox2DEditorXIndex.setProperty("value", 0)
        self.spinBox2DEditorXIndex.setObjectName(_fromUtf8("spinBox2DEditorXIndex"))
        self.gridLayout_6.addWidget(self.spinBox2DEditorXIndex, 1, 2, 1, 1)
        self.horizontalSlider2DEditorXIndex = QtGui.QSlider(self.dockWidgetContents2DEditorYZ)
        self.horizontalSlider2DEditorXIndex.setMinimum(0)
        self.horizontalSlider2DEditorXIndex.setMaximum(999)
        self.horizontalSlider2DEditorXIndex.setProperty("value", 0)
        self.horizontalSlider2DEditorXIndex.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider2DEditorXIndex.setTickPosition(QtGui.QSlider.NoTicks)
        self.horizontalSlider2DEditorXIndex.setObjectName(_fromUtf8("horizontalSlider2DEditorXIndex"))
        self.gridLayout_6.addWidget(self.horizontalSlider2DEditorXIndex, 1, 3, 1, 1)
        self.tableWidget2DEditorYZ = QtGui.QTableWidget(self.dockWidgetContents2DEditorYZ)
        self.tableWidget2DEditorYZ.setObjectName(_fromUtf8("tableWidget2DEditorYZ"))
        self.tableWidget2DEditorYZ.setColumnCount(0)
        self.tableWidget2DEditorYZ.setRowCount(0)
        self.gridLayout_6.addWidget(self.tableWidget2DEditorYZ, 0, 1, 1, 3)
        self.dockWidget2DEditorYZ.setWidget(self.dockWidgetContents2DEditorYZ)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dockWidget2DEditorYZ)
        self.dockWidget2DEditorXZ = QtGui.QDockWidget(MainWindow)
        self.dockWidget2DEditorXZ.setFeatures(QtGui.QDockWidget.DockWidgetFloatable|QtGui.QDockWidget.DockWidgetMovable)
        self.dockWidget2DEditorXZ.setObjectName(_fromUtf8("dockWidget2DEditorXZ"))
        self.dockWidgetContents2DEditorXZ = QtGui.QWidget()
        self.dockWidgetContents2DEditorXZ.setObjectName(_fromUtf8("dockWidgetContents2DEditorXZ"))
        self.gridLayout_7 = QtGui.QGridLayout(self.dockWidgetContents2DEditorXZ)
        self.gridLayout_7.setObjectName(_fromUtf8("gridLayout_7"))
        self.label2DEditorYIndex = QtGui.QLabel(self.dockWidgetContents2DEditorXZ)
        self.label2DEditorYIndex.setObjectName(_fromUtf8("label2DEditorYIndex"))
        self.gridLayout_7.addWidget(self.label2DEditorYIndex, 1, 0, 1, 1)
        self.spinBox2DEditorYIndex = QtGui.QSpinBox(self.dockWidgetContents2DEditorXZ)
        self.spinBox2DEditorYIndex.setMinimum(0)
        self.spinBox2DEditorYIndex.setMaximum(999)
        self.spinBox2DEditorYIndex.setProperty("value", 0)
        self.spinBox2DEditorYIndex.setObjectName(_fromUtf8("spinBox2DEditorYIndex"))
        self.gridLayout_7.addWidget(self.spinBox2DEditorYIndex, 1, 1, 1, 1)
        self.horizontalSlider2DEditorYIndex = QtGui.QSlider(self.dockWidgetContents2DEditorXZ)
        self.horizontalSlider2DEditorYIndex.setMinimum(0)
        self.horizontalSlider2DEditorYIndex.setMaximum(999)
        self.horizontalSlider2DEditorYIndex.setProperty("value", 0)
        self.horizontalSlider2DEditorYIndex.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider2DEditorYIndex.setTickPosition(QtGui.QSlider.NoTicks)
        self.horizontalSlider2DEditorYIndex.setObjectName(_fromUtf8("horizontalSlider2DEditorYIndex"))
        self.gridLayout_7.addWidget(self.horizontalSlider2DEditorYIndex, 1, 2, 1, 1)
        self.tableWidget2DEditorXZ = QtGui.QTableWidget(self.dockWidgetContents2DEditorXZ)
        self.tableWidget2DEditorXZ.setObjectName(_fromUtf8("tableWidget2DEditorXZ"))
        self.tableWidget2DEditorXZ.setColumnCount(0)
        self.tableWidget2DEditorXZ.setRowCount(0)
        self.gridLayout_7.addWidget(self.tableWidget2DEditorXZ, 0, 0, 1, 3)
        self.dockWidget2DEditorXZ.setWidget(self.dockWidgetContents2DEditorXZ)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dockWidget2DEditorXZ)
        self.toolBarContext = QtGui.QToolBar(MainWindow)
        self.toolBarContext.setIconSize(QtCore.QSize(42, 42))
        self.toolBarContext.setObjectName(_fromUtf8("toolBarContext"))
        MainWindow.addToolBar(QtCore.Qt.LeftToolBarArea, self.toolBarContext)
        self.toolBar3DView = QtGui.QToolBar(MainWindow)
        self.toolBar3DView.setIconSize(QtCore.QSize(32, 32))
        self.toolBar3DView.setObjectName(_fromUtf8("toolBar3DView"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar3DView)
        self.statusBar = QtGui.QStatusBar(MainWindow)
        self.statusBar.setObjectName(_fromUtf8("statusBar"))
        MainWindow.setStatusBar(self.statusBar)
        self.toolBarFile = QtGui.QToolBar(MainWindow)
        self.toolBarFile.setIconSize(QtCore.QSize(32, 32))
        self.toolBarFile.setObjectName(_fromUtf8("toolBarFile"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBarFile)
        self.toolBarFieldInhomogeneity = QtGui.QToolBar(MainWindow)
        self.toolBarFieldInhomogeneity.setIconSize(QtCore.QSize(42, 42))
        self.toolBarFieldInhomogeneity.setObjectName(_fromUtf8("toolBarFieldInhomogeneity"))
        MainWindow.addToolBar(QtCore.Qt.LeftToolBarArea, self.toolBarFieldInhomogeneity)
        self.toolBarFileSequence = QtGui.QToolBar(MainWindow)
        self.toolBarFileSequence.setIconSize(QtCore.QSize(32, 32))
        self.toolBarFileSequence.setObjectName(_fromUtf8("toolBarFileSequence"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBarFileSequence)
        self.toolBarSimulator = QtGui.QToolBar(MainWindow)
        self.toolBarSimulator.setIconSize(QtCore.QSize(42, 42))
        self.toolBarSimulator.setObjectName(_fromUtf8("toolBarSimulator"))
        MainWindow.addToolBar(QtCore.Qt.LeftToolBarArea, self.toolBarSimulator)
        self.dockWidgetExplorer = QtGui.QDockWidget(MainWindow)
        self.dockWidgetExplorer.setObjectName(_fromUtf8("dockWidgetExplorer"))
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName(_fromUtf8("dockWidgetContents"))
        self.dockWidgetExplorer.setWidget(self.dockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dockWidgetExplorer)
        self.actionSampleElementT1 = QtGui.QAction(MainWindow)
        self.actionSampleElementT1.setCheckable(True)
        self.actionSampleElementT1.setChecked(True)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/SampleElementT1.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSampleElementT1.setIcon(icon)
        self.actionSampleElementT1.setIconVisibleInMenu(True)
        self.actionSampleElementT1.setObjectName(_fromUtf8("actionSampleElementT1"))
        self.actionSampleElementT2 = QtGui.QAction(MainWindow)
        self.actionSampleElementT2.setCheckable(True)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/SampleElementT2.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSampleElementT2.setIcon(icon1)
        self.actionSampleElementT2.setIconVisibleInMenu(True)
        self.actionSampleElementT2.setObjectName(_fromUtf8("actionSampleElementT2"))
        self.actionSampleElementRho = QtGui.QAction(MainWindow)
        self.actionSampleElementRho.setCheckable(True)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/SampleElementRho.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSampleElementRho.setIcon(icon2)
        self.actionSampleElementRho.setIconVisibleInMenu(True)
        self.actionSampleElementRho.setObjectName(_fromUtf8("actionSampleElementRho"))
        self.action2DEditorXY = QtGui.QAction(MainWindow)
        self.action2DEditorXY.setCheckable(True)
        self.action2DEditorXY.setChecked(False)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/2DEditorXY.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action2DEditorXY.setIcon(icon3)
        self.action2DEditorXY.setIconVisibleInMenu(True)
        self.action2DEditorXY.setObjectName(_fromUtf8("action2DEditorXY"))
        self.action2DEditorXZ = QtGui.QAction(MainWindow)
        self.action2DEditorXZ.setCheckable(True)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/2DEditorXZ.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action2DEditorXZ.setIcon(icon4)
        self.action2DEditorXZ.setIconVisibleInMenu(True)
        self.action2DEditorXZ.setObjectName(_fromUtf8("action2DEditorXZ"))
        self.action2DEditorYZ = QtGui.QAction(MainWindow)
        self.action2DEditorYZ.setCheckable(True)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/2DEditorYZ.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action2DEditorYZ.setIcon(icon5)
        self.action2DEditorYZ.setIconVisibleInMenu(True)
        self.action2DEditorYZ.setObjectName(_fromUtf8("action2DEditorYZ"))
        self.action3DViewColor = QtGui.QAction(MainWindow)
        self.action3DViewColor.setCheckable(True)
        self.action3DViewColor.setChecked(True)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewColor.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewColor.setIcon(icon6)
        self.action3DViewColor.setIconVisibleInMenu(True)
        self.action3DViewColor.setObjectName(_fromUtf8("action3DViewColor"))
        self.actionFileNew = QtGui.QAction(MainWindow)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/FileNew.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFileNew.setIcon(icon7)
        self.actionFileNew.setObjectName(_fromUtf8("actionFileNew"))
        self.actionFileOpen = QtGui.QAction(MainWindow)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/FileOpen.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFileOpen.setIcon(icon8)
        self.actionFileOpen.setObjectName(_fromUtf8("actionFileOpen"))
        self.actionFileSave = QtGui.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/FileSave.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFileSave.setIcon(icon9)
        self.actionFileSave.setObjectName(_fromUtf8("actionFileSave"))
        self.actionFileSaveAs = QtGui.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/FileSaveAs.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFileSaveAs.setIcon(icon10)
        self.actionFileSaveAs.setObjectName(_fromUtf8("actionFileSaveAs"))
        self.actionFileClose = QtGui.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/FileClose.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFileClose.setIcon(icon11)
        self.actionFileClose.setObjectName(_fromUtf8("actionFileClose"))
        self.actionQuit = QtGui.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/Quit.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionQuit.setIcon(icon12)
        self.actionQuit.setObjectName(_fromUtf8("actionQuit"))
        self.actionFileExamples = QtGui.QAction(MainWindow)
        self.actionFileExamples.setObjectName(_fromUtf8("actionFileExamples"))
        self.action2DEditorXYZ = QtGui.QAction(MainWindow)
        self.action2DEditorXYZ.setCheckable(True)
        self.action2DEditorXYZ.setChecked(True)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/2DEditorXYZ.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action2DEditorXYZ.setIcon(icon13)
        self.action2DEditorXYZ.setIconVisibleInMenu(True)
        self.action2DEditorXYZ.setObjectName(_fromUtf8("action2DEditorXYZ"))
        self.actionConfigurationPreferences = QtGui.QAction(MainWindow)
        self.actionConfigurationPreferences.setIconVisibleInMenu(True)
        self.actionConfigurationPreferences.setObjectName(_fromUtf8("actionConfigurationPreferences"))
        self.action3DView = QtGui.QAction(MainWindow)
        self.action3DView.setCheckable(True)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DView.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DView.setIcon(icon14)
        self.action3DView.setObjectName(_fromUtf8("action3DView"))
        self.action2DEditorGradient = QtGui.QAction(MainWindow)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/2DEditorGradient.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action2DEditorGradient.setIcon(icon15)
        self.action2DEditorGradient.setObjectName(_fromUtf8("action2DEditorGradient"))
        self.action3DViewCameraXYZ = QtGui.QAction(MainWindow)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewXYZ.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewCameraXYZ.setIcon(icon16)
        self.action3DViewCameraXYZ.setIconVisibleInMenu(True)
        self.action3DViewCameraXYZ.setObjectName(_fromUtf8("action3DViewCameraXYZ"))
        self.action3DViewCameraXY = QtGui.QAction(MainWindow)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewXY.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewCameraXY.setIcon(icon17)
        self.action3DViewCameraXY.setIconVisibleInMenu(True)
        self.action3DViewCameraXY.setObjectName(_fromUtf8("action3DViewCameraXY"))
        self.action3DViewCameraXZ = QtGui.QAction(MainWindow)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewXZ.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewCameraXZ.setIcon(icon18)
        self.action3DViewCameraXZ.setIconVisibleInMenu(True)
        self.action3DViewCameraXZ.setObjectName(_fromUtf8("action3DViewCameraXZ"))
        self.action3DViewCameraYZ = QtGui.QAction(MainWindow)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewYZ.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewCameraYZ.setIcon(icon19)
        self.action3DViewCameraYZ.setIconVisibleInMenu(True)
        self.action3DViewCameraYZ.setObjectName(_fromUtf8("action3DViewCameraYZ"))
        self.actionContextSample = QtGui.QAction(MainWindow)
        self.actionContextSample.setCheckable(True)
        self.actionContextSample.setChecked(True)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/ContextSubject.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionContextSample.setIcon(icon20)
        self.actionContextSample.setObjectName(_fromUtf8("actionContextSample"))
        self.actionContextSystem = QtGui.QAction(MainWindow)
        self.actionContextSystem.setCheckable(True)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/ContextSystem.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionContextSystem.setIcon(icon21)
        self.actionContextSystem.setObjectName(_fromUtf8("actionContextSystem"))
        self.actionContextSequence = QtGui.QAction(MainWindow)
        self.actionContextSequence.setCheckable(True)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/ContextSequence.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionContextSequence.setIcon(icon22)
        self.actionContextSequence.setObjectName(_fromUtf8("actionContextSequence"))
        self.actionContextProcessing = QtGui.QAction(MainWindow)
        self.actionContextProcessing.setCheckable(True)
        icon23 = QtGui.QIcon()
        icon23.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/ContextProcessing.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionContextProcessing.setIcon(icon23)
        self.actionContextProcessing.setObjectName(_fromUtf8("actionContextProcessing"))
        self.action2DEditorColor = QtGui.QAction(MainWindow)
        self.action2DEditorColor.setCheckable(True)
        self.action2DEditorColor.setChecked(True)
        icon24 = QtGui.QIcon()
        icon24.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/2DEditorColor.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action2DEditorColor.setIcon(icon24)
        self.action2DEditorColor.setIconVisibleInMenu(True)
        self.action2DEditorColor.setObjectName(_fromUtf8("action2DEditorColor"))
        self.actionSampleElementAll = QtGui.QAction(MainWindow)
        self.actionSampleElementAll.setCheckable(True)
        self.actionSampleElementAll.setObjectName(_fromUtf8("actionSampleElementAll"))
        self.action2DEditor = QtGui.QAction(MainWindow)
        self.action2DEditor.setCheckable(True)
        icon25 = QtGui.QIcon()
        icon25.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/2DEditor.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action2DEditor.setIcon(icon25)
        self.action2DEditor.setIconVisibleInMenu(True)
        self.action2DEditor.setObjectName(_fromUtf8("action2DEditor"))
        self.action3DViewXGrid = QtGui.QAction(MainWindow)
        self.action3DViewXGrid.setCheckable(True)
        self.action3DViewXGrid.setChecked(True)
        icon26 = QtGui.QIcon()
        icon26.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewGridX.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewXGrid.setIcon(icon26)
        self.action3DViewXGrid.setIconVisibleInMenu(True)
        self.action3DViewXGrid.setObjectName(_fromUtf8("action3DViewXGrid"))
        self.action3DViewYGrid = QtGui.QAction(MainWindow)
        self.action3DViewYGrid.setCheckable(True)
        self.action3DViewYGrid.setChecked(True)
        icon27 = QtGui.QIcon()
        icon27.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewGridY.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewYGrid.setIcon(icon27)
        self.action3DViewYGrid.setIconVisibleInMenu(True)
        self.action3DViewYGrid.setObjectName(_fromUtf8("action3DViewYGrid"))
        self.action3DViewZGrid = QtGui.QAction(MainWindow)
        self.action3DViewZGrid.setCheckable(True)
        self.action3DViewZGrid.setChecked(True)
        icon28 = QtGui.QIcon()
        icon28.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewGridZ.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewZGrid.setIcon(icon28)
        self.action3DViewZGrid.setIconVisibleInMenu(True)
        self.action3DViewZGrid.setObjectName(_fromUtf8("action3DViewZGrid"))
        self.action3DViewXYZAxis = QtGui.QAction(MainWindow)
        self.action3DViewXYZAxis.setCheckable(True)
        self.action3DViewXYZAxis.setChecked(True)
        icon29 = QtGui.QIcon()
        icon29.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewAxisXYZ.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewXYZAxis.setIcon(icon29)
        self.action3DViewXYZAxis.setIconVisibleInMenu(True)
        self.action3DViewXYZAxis.setObjectName(_fromUtf8("action3DViewXYZAxis"))
        self.action3DViewInvertBackground = QtGui.QAction(MainWindow)
        self.action3DViewInvertBackground.setCheckable(True)
        icon30 = QtGui.QIcon()
        icon30.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/3DViewInvertBackground.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action3DViewInvertBackground.setIcon(icon30)
        self.action3DViewInvertBackground.setIconVisibleInMenu(True)
        self.action3DViewInvertBackground.setObjectName(_fromUtf8("action3DViewInvertBackground"))
        self.action2DEditorInvertBackground = QtGui.QAction(MainWindow)
        self.action2DEditorInvertBackground.setIcon(icon30)
        self.action2DEditorInvertBackground.setObjectName(_fromUtf8("action2DEditorInvertBackground"))
        self.actionContextSimulator = QtGui.QAction(MainWindow)
        self.actionContextSimulator.setCheckable(True)
        icon31 = QtGui.QIcon()
        icon31.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/ContextSimulator.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionContextSimulator.setIcon(icon31)
        self.actionContextSimulator.setObjectName(_fromUtf8("actionContextSimulator"))
        self.actionFieldInhomogeneityB0X = QtGui.QAction(MainWindow)
        self.actionFieldInhomogeneityB0X.setCheckable(True)
        icon32 = QtGui.QIcon()
        icon32.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/FieldInhomogeneityB0X.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFieldInhomogeneityB0X.setIcon(icon32)
        self.actionFieldInhomogeneityB0X.setObjectName(_fromUtf8("actionFieldInhomogeneityB0X"))
        self.actionFieldInhomogeneityB0Y = QtGui.QAction(MainWindow)
        self.actionFieldInhomogeneityB0Y.setCheckable(True)
        icon33 = QtGui.QIcon()
        icon33.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/FieldInhomogeneityB0Y.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFieldInhomogeneityB0Y.setIcon(icon33)
        self.actionFieldInhomogeneityB0Y.setObjectName(_fromUtf8("actionFieldInhomogeneityB0Y"))
        self.actionFieldInhomogeneityB0Z = QtGui.QAction(MainWindow)
        self.actionFieldInhomogeneityB0Z.setCheckable(True)
        icon34 = QtGui.QIcon()
        icon34.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/FieldInhomogeneityB0Z.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionFieldInhomogeneityB0Z.setIcon(icon34)
        self.actionFieldInhomogeneityB0Z.setObjectName(_fromUtf8("actionFieldInhomogeneityB0Z"))
        self.actionFieldInhomogeneityAll = QtGui.QAction(MainWindow)
        self.actionFieldInhomogeneityAll.setCheckable(True)
        self.actionFieldInhomogeneityAll.setObjectName(_fromUtf8("actionFieldInhomogeneityAll"))
        self.actionFileSequenceOpen = QtGui.QAction(MainWindow)
        self.actionFileSequenceOpen.setIcon(icon8)
        self.actionFileSequenceOpen.setObjectName(_fromUtf8("actionFileSequenceOpen"))
        self.actionSimulatorRun = QtGui.QAction(MainWindow)
        icon35 = QtGui.QIcon()
        icon35.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/SimulatorPlay.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSimulatorRun.setIcon(icon35)
        self.actionSimulatorRun.setObjectName(_fromUtf8("actionSimulatorRun"))
        self.actionSimulatorPlay = QtGui.QAction(MainWindow)
        self.actionSimulatorPlay.setIcon(icon35)
        self.actionSimulatorPlay.setObjectName(_fromUtf8("actionSimulatorPlay"))
        self.actionSimulatorStop = QtGui.QAction(MainWindow)
        icon36 = QtGui.QIcon()
        icon36.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/SimulatorStop.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSimulatorStop.setIcon(icon36)
        self.actionSimulatorStop.setObjectName(_fromUtf8("actionSimulatorStop"))
        self.actionSimulatorPause = QtGui.QAction(MainWindow)
        icon37 = QtGui.QIcon()
        icon37.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/SimulatorPause.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSimulatorPause.setIcon(icon37)
        self.actionSimulatorPause.setObjectName(_fromUtf8("actionSimulatorPause"))
        self.actionSimulatorCalculate = QtGui.QAction(MainWindow)
        icon38 = QtGui.QIcon()
        icon38.addPixmap(QtGui.QPixmap(_fromUtf8(":/mrsprint/SimulatorCalculate.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSimulatorCalculate.setIcon(icon38)
        self.actionSimulatorCalculate.setObjectName(_fromUtf8("actionSimulatorCalculate"))
        self.toolBarSampleElement.addAction(self.actionSampleElementT1)
        self.toolBarSampleElement.addAction(self.actionSampleElementT2)
        self.toolBarSampleElement.addAction(self.actionSampleElementRho)
        self.toolBarSampleElement.addAction(self.actionSampleElementAll)
        self.toolBar2DEditor.addAction(self.action2DEditorXY)
        self.toolBar2DEditor.addAction(self.action2DEditorXZ)
        self.toolBar2DEditor.addAction(self.action2DEditorYZ)
        self.toolBar2DEditor.addSeparator()
        self.toolBar2DEditor.addAction(self.action2DEditorXYZ)
        self.toolBar2DEditor.addSeparator()
        self.toolBar2DEditor.addAction(self.action2DEditorColor)
        self.toolBar2DEditor.addSeparator()
        self.toolBar2DEditor.addAction(self.action2DEditorGradient)
        self.toolBar3DViewCamera.addAction(self.action3DViewCameraXY)
        self.toolBar3DViewCamera.addAction(self.action3DViewCameraXZ)
        self.toolBar3DViewCamera.addAction(self.action3DViewCameraYZ)
        self.toolBar3DViewCamera.addSeparator()
        self.toolBar3DViewCamera.addAction(self.action3DViewCameraXYZ)
        self.menuFile.addAction(self.actionFileNew)
        self.menuFile.addAction(self.actionFileOpen)
        self.menuFile.addAction(self.actionFileExamples)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionFileSave)
        self.menuFile.addAction(self.actionFileSaveAs)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionFileClose)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuSampleElement.addAction(self.actionSampleElementT1)
        self.menuSampleElement.addAction(self.actionSampleElementT2)
        self.menuSampleElement.addAction(self.actionSampleElementRho)
        self.menuConfiguration.addAction(self.actionConfigurationPreferences)
        self.menu2DEditor.addAction(self.action2DEditorXY)
        self.menu2DEditor.addAction(self.action2DEditorXZ)
        self.menu2DEditor.addAction(self.action2DEditorYZ)
        self.menu2DEditor.addSeparator()
        self.menu2DEditor.addAction(self.action2DEditorXYZ)
        self.menu2DEditor.addSeparator()
        self.menu2DEditor.addAction(self.action2DEditorColor)
        self.menu2DEditor.addSeparator()
        self.menu2DEditor.addAction(self.action2DEditor)
        self.menu2DEditor.addSeparator()
        self.menu2DEditor.addAction(self.action2DEditorInvertBackground)
        self.menu3DView.addSeparator()
        self.menu3DView.addAction(self.action3DViewCameraXY)
        self.menu3DView.addAction(self.action3DViewCameraXZ)
        self.menu3DView.addAction(self.action3DViewCameraYZ)
        self.menu3DView.addAction(self.action3DViewCameraXYZ)
        self.menu3DView.addSeparator()
        self.menu3DView.addAction(self.action3DViewXGrid)
        self.menu3DView.addAction(self.action3DViewYGrid)
        self.menu3DView.addAction(self.action3DViewZGrid)
        self.menu3DView.addSeparator()
        self.menu3DView.addAction(self.action3DViewXYZAxis)
        self.menu3DView.addSeparator()
        self.menu3DView.addAction(self.action3DViewColor)
        self.menu3DView.addSeparator()
        self.menu3DView.addAction(self.action3DViewInvertBackground)
        self.menu3DView.addSeparator()
        self.menu3DView.addSeparator()
        self.menu3DView.addAction(self.action3DView)
        self.menuBar.addAction(self.menuFile.menuAction())
        self.menuBar.addAction(self.menuEdit.menuAction())
        self.menuBar.addAction(self.menuSampleElement.menuAction())
        self.menuBar.addAction(self.menu2DEditor.menuAction())
        self.menuBar.addAction(self.menu3DView.menuAction())
        self.menuBar.addAction(self.menuConfiguration.menuAction())
        self.menuBar.addAction(self.menuHelp.menuAction())
        self.toolBarContext.addAction(self.actionContextSample)
        self.toolBarContext.addAction(self.actionContextSystem)
        self.toolBarContext.addAction(self.actionContextSequence)
        self.toolBarContext.addAction(self.actionContextSimulator)
        self.toolBarContext.addAction(self.actionContextProcessing)
        self.toolBar3DView.addAction(self.action3DViewColor)
        self.toolBar3DView.addSeparator()
        self.toolBar3DView.addAction(self.action3DViewXGrid)
        self.toolBar3DView.addAction(self.action3DViewYGrid)
        self.toolBar3DView.addAction(self.action3DViewZGrid)
        self.toolBar3DView.addSeparator()
        self.toolBar3DView.addAction(self.action3DViewXYZAxis)
        self.toolBarFile.addAction(self.actionFileNew)
        self.toolBarFile.addAction(self.actionFileOpen)
        self.toolBarFile.addAction(self.actionFileSave)
        self.toolBarFieldInhomogeneity.addAction(self.actionFieldInhomogeneityB0X)
        self.toolBarFieldInhomogeneity.addAction(self.actionFieldInhomogeneityB0Y)
        self.toolBarFieldInhomogeneity.addAction(self.actionFieldInhomogeneityB0Z)
        self.toolBarFieldInhomogeneity.addAction(self.actionFieldInhomogeneityAll)
        self.toolBarFileSequence.addAction(self.actionFileSequenceOpen)
        self.toolBarSimulator.addAction(self.actionSimulatorCalculate)
        self.toolBarSimulator.addAction(self.actionSimulatorRun)
        self.toolBarSimulator.addAction(self.actionSimulatorPlay)
        self.toolBarSimulator.addAction(self.actionSimulatorPause)
        self.toolBarSimulator.addAction(self.actionSimulatorStop)

        self.retranslateUi(MainWindow)
        QtCore.QObject.connect(self.action2DEditorXYZ, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.action2DEditorXY.setDisabled)
        QtCore.QObject.connect(self.action2DEditorXYZ, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.action2DEditorXZ.setDisabled)
        QtCore.QObject.connect(self.action2DEditorXYZ, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.action2DEditorYZ.setDisabled)
        QtCore.QObject.connect(self.horizontalSlider2DEditorZIndex, QtCore.SIGNAL(_fromUtf8("sliderMoved(int)")), self.spinBox2DEditorZIndex.setValue)
        QtCore.QObject.connect(self.horizontalSlider2DEditorXIndex, QtCore.SIGNAL(_fromUtf8("sliderMoved(int)")), self.spinBox2DEditorXIndex.setValue)
        QtCore.QObject.connect(self.horizontalSlider2DEditorYIndex, QtCore.SIGNAL(_fromUtf8("sliderMoved(int)")), self.spinBox2DEditorYIndex.setValue)
        QtCore.QObject.connect(self.spinBox2DEditorZIndex, QtCore.SIGNAL(_fromUtf8("valueChanged(int)")), self.horizontalSlider2DEditorZIndex.setValue)
        QtCore.QObject.connect(self.spinBox2DEditorXIndex, QtCore.SIGNAL(_fromUtf8("valueChanged(int)")), self.horizontalSlider2DEditorXIndex.setValue)
        QtCore.QObject.connect(self.spinBox2DEditorYIndex, QtCore.SIGNAL(_fromUtf8("valueChanged(int)")), self.horizontalSlider2DEditorYIndex.setValue)
        QtCore.QObject.connect(self.action3DView, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.action3DViewCameraXYZ.setEnabled)
        QtCore.QObject.connect(self.action3DView, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.action3DViewCameraXY.setEnabled)
        QtCore.QObject.connect(self.action3DView, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.action3DViewCameraXZ.setEnabled)
        QtCore.QObject.connect(self.action3DView, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.action3DViewCameraYZ.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(_translate("MainWindow", "Precession", None))
        self.toolBarSampleElement.setWindowTitle(_translate("MainWindow", "Tool Bar Sample Element", None))
        self.toolBarSampleElement.setToolTip(_translate("MainWindow", "Sample related actions", None))
        self.toolBar2DEditor.setWindowTitle(_translate("MainWindow", "Tool Bar 2D Editor", None))
        self.toolBar2DEditor.setToolTip(_translate("MainWindow", "2D editor related actions", None))
        self.toolBar3DViewCamera.setWindowTitle(_translate("MainWindow", "Tool Bar 3D View Camera", None))
        self.toolBar3DViewCamera.setToolTip(_translate("MainWindow", " 3D view camera related actions", None))
        self.dockWidgetParameters.setWindowTitle(_translate("MainWindow", "Parameters", None))
        self.dockWidget2DEditorXY.setWindowTitle(_translate("MainWindow", "Axial - Plane XY", None))
        self.label2DEditorZIndex.setText(_translate("MainWindow", "Z Index", None))
        self.menuFile.setTitle(_translate("MainWindow", "File", None))
        self.menuSampleElement.setTitle(_translate("MainWindow", "Sample", None))
        self.menuHelp.setTitle(_translate("MainWindow", "Help", None))
        self.menuConfiguration.setTitle(_translate("MainWindow", "Settings", None))
        self.menu2DEditor.setTitle(_translate("MainWindow", "2D Editor", None))
        self.menu3DView.setTitle(_translate("MainWindow", "3D View", None))
        self.menuEdit.setTitle(_translate("MainWindow", "Edit", None))
        self.dockWidget2DEditorYZ.setWindowTitle(_translate("MainWindow", "Sagittal - Plane YZ", None))
        self.label2DEditorXIndex.setText(_translate("MainWindow", "X Index", None))
        self.dockWidget2DEditorXZ.setWindowTitle(_translate("MainWindow", "Coronal - Plane XZ", None))
        self.label2DEditorYIndex.setText(_translate("MainWindow", "Y Index", None))
        self.toolBarContext.setWindowTitle(_translate("MainWindow", "Tool Bar Context Menu", None))
        self.toolBarContext.setToolTip(_translate("MainWindow", "Main window context/perspective", None))
        self.toolBar3DView.setWindowTitle(_translate("MainWindow", "Tool Bar 3D View", None))
        self.toolBar3DView.setToolTip(_translate("MainWindow", "3D view related actions", None))
        self.toolBarFile.setWindowTitle(_translate("MainWindow", "Tool Bar File", None))
        self.toolBarFile.setToolTip(_translate("MainWindow", "File related actions", None))
        self.toolBarFieldInhomogeneity.setWindowTitle(_translate("MainWindow", "Tool Bar Field Inhomogeneity", None))
        self.toolBarFieldInhomogeneity.setToolTip(_translate("MainWindow", "System related actions, field inhomogeneity", None))
        self.toolBarFileSequence.setWindowTitle(_translate("MainWindow", "toolBarFileSequence", None))
        self.toolBarFileSequence.setToolTip(_translate("MainWindow", "File related actions", None))
        self.toolBarSimulator.setWindowTitle(_translate("MainWindow", "toolBar", None))
        self.dockWidgetExplorer.setToolTip(_translate("MainWindow", "Find files to be load.", None))
        self.dockWidgetExplorer.setWindowTitle(_translate("MainWindow", "Explorer", None))
        self.actionSampleElementT1.setText(_translate("MainWindow", "T1", None))
        self.actionSampleElementT2.setText(_translate("MainWindow", "T2", None))
        self.actionSampleElementRho.setText(_translate("MainWindow", "ρ", None))
        self.action2DEditorXY.setText(_translate("MainWindow", "Axial (XY)", None))
        self.action2DEditorXZ.setText(_translate("MainWindow", "Coronal (XZ)", None))
        self.action2DEditorYZ.setText(_translate("MainWindow", "Sagittal (YZ)", None))
        self.action3DViewColor.setText(_translate("MainWindow", "Color", None))
        self.action3DViewColor.setToolTip(_translate("MainWindow", "Represents parameters on colors", None))
        self.actionFileNew.setText(_translate("MainWindow", "New", None))
        self.actionFileOpen.setText(_translate("MainWindow", "Open ...", None))
        self.actionFileSave.setText(_translate("MainWindow", "Save", None))
        self.actionFileSaveAs.setText(_translate("MainWindow", "Save As ...", None))
        self.actionFileClose.setText(_translate("MainWindow", "Close", None))
        self.actionQuit.setText(_translate("MainWindow", "Quit", None))
        self.actionFileExamples.setText(_translate("MainWindow", "Examples", None))
        self.action2DEditorXYZ.setText(_translate("MainWindow", "All", None))
        self.action2DEditorXYZ.setToolTip(_translate("MainWindow", "All 2D editors are opened/closed", None))
        self.actionConfigurationPreferences.setText(_translate("MainWindow", "Preferences ...", None))
        self.action3DView.setText(_translate("MainWindow", "3D View", None))
        self.action3DView.setToolTip(_translate("MainWindow", "Enable/Disable 3D View", None))
        self.action2DEditorGradient.setText(_translate("MainWindow", "Gradient", None))
        self.action2DEditorGradient.setToolTip(_translate("MainWindow", "Creates a gradient over values", None))
        self.action3DViewCameraXYZ.setText(_translate("MainWindow", "Camera Diagonal (XYZ)", None))
        self.action3DViewCameraXYZ.setToolTip(_translate("MainWindow", "Diagonal View", None))
        self.action3DViewCameraXY.setText(_translate("MainWindow", "Camera Axial (XY)", None))
        self.action3DViewCameraXY.setToolTip(_translate("MainWindow", "Axial View", None))
        self.action3DViewCameraXZ.setText(_translate("MainWindow", "Camera Coronal (XZ)", None))
        self.action3DViewCameraXZ.setToolTip(_translate("MainWindow", "Coronal View", None))
        self.action3DViewCameraYZ.setText(_translate("MainWindow", "Camera Sagittal (YZ)", None))
        self.action3DViewCameraYZ.setToolTip(_translate("MainWindow", "Sagittal View", None))
        self.actionContextSample.setText(_translate("MainWindow", "Sample", None))
        self.actionContextSample.setToolTip(_translate("MainWindow", "Sample editor context", None))
        self.actionContextSystem.setText(_translate("MainWindow", "System", None))
        self.actionContextSystem.setToolTip(_translate("MainWindow", "System editor context", None))
        self.actionContextSequence.setText(_translate("MainWindow", "Sequence", None))
        self.actionContextSequence.setToolTip(_translate("MainWindow", "Sequence editor context", None))
        self.actionContextProcessing.setText(_translate("MainWindow", "Processing", None))
        self.actionContextProcessing.setToolTip(_translate("MainWindow", "Processing editor context", None))
        self.action2DEditorColor.setText(_translate("MainWindow", "Color", None))
        self.action2DEditorColor.setToolTip(_translate("MainWindow", "Enable/disable colors over 2D editor", None))
        self.actionSampleElementAll.setText(_translate("MainWindow", "All", None))
        self.actionSampleElementAll.setToolTip(_translate("MainWindow", "Show all element sample paremeters", None))
        self.action2DEditor.setText(_translate("MainWindow", "2D Editor", None))
        self.action2DEditor.setToolTip(_translate("MainWindow", "Show 2D editor", None))
        self.action3DViewXGrid.setText(_translate("MainWindow", "X Grid", None))
        self.action3DViewYGrid.setText(_translate("MainWindow", "Y Grid", None))
        self.action3DViewZGrid.setText(_translate("MainWindow", "Z Grid", None))
        self.action3DViewXYZAxis.setText(_translate("MainWindow", "XYZ Axis", None))
        self.action3DViewInvertBackground.setText(_translate("MainWindow", "Invert Background", None))
        self.action2DEditorInvertBackground.setText(_translate("MainWindow", "Invert Background", None))
        self.actionContextSimulator.setText(_translate("MainWindow", "Simulator", None))
        self.actionFieldInhomogeneityB0X.setText(_translate("MainWindow", "Field Inhomogeneity B0X", None))
        self.actionFieldInhomogeneityB0X.setToolTip(_translate("MainWindow", "Field Inhomogeneity B0X", None))
        self.actionFieldInhomogeneityB0Y.setText(_translate("MainWindow", "Field Inhomogeneity  B0Y", None))
        self.actionFieldInhomogeneityB0Y.setToolTip(_translate("MainWindow", "Field Inhomogeneity B0Y", None))
        self.actionFieldInhomogeneityB0Z.setText(_translate("MainWindow", "Field Inhomogeneity B0Z", None))
        self.actionFieldInhomogeneityB0Z.setToolTip(_translate("MainWindow", "Field Inhomogeneity B0Z", None))
        self.actionFieldInhomogeneityAll.setText(_translate("MainWindow", "All", None))
        self.actionFieldInhomogeneityAll.setToolTip(_translate("MainWindow", "Field inhomogeneity resultant component", None))
        self.actionFileSequenceOpen.setText(_translate("MainWindow", "FileSequence", None))
        self.actionFileSequenceOpen.setToolTip(_translate("MainWindow", "Open", None))
        self.actionSimulatorRun.setText(_translate("MainWindow", "Run", None))
        self.actionSimulatorRun.setToolTip(_translate("MainWindow", "Run (Calculate and play simulator)", None))
        self.actionSimulatorPlay.setText(_translate("MainWindow", "Play", None))
        self.actionSimulatorPlay.setToolTip(_translate("MainWindow", "Play a simulated data", None))
        self.actionSimulatorStop.setText(_translate("MainWindow", "Stop", None))
        self.actionSimulatorStop.setToolTip(_translate("MainWindow", "Stop simulation (calculation and/or play)", None))
        self.actionSimulatorPause.setText(_translate("MainWindow", "Pause", None))
        self.actionSimulatorPause.setToolTip(_translate("MainWindow", "Pause a play", None))
        self.actionSimulatorCalculate.setText(_translate("MainWindow", "Calculate", None))
        self.actionSimulatorCalculate.setToolTip(_translate("MainWindow", "Calculate simulation data (do not play)", None))

from . import mrsprint_rc



#! python
# -*- coding: utf-8 -*-

"""Module for simulate the response of the sample to the magnetic signal related classes and functions.

Authors:
    * Victor Hugo de Mello Pessoa <victor.pessoa@usp.br>
    * Daniel Cosmo Pizetta <daniel.pizetta@usp.br>

Since:
    2017/07/01

"""


import logging

import pyqtgraph.parametertree as pt

_logger = logging.getLogger(__name__)


class Simulator(pt.parameterTypes.GroupParameter):
    """Class that represents the simulator."""

    def __init__(self, **opts):
        opts['name'] = 'Simulator'
        opts['type'] = 'bool'
        opts['value'] = True
        pt.parameterTypes.GroupParameter.__init__(self, **opts)

        # modes
        self.magnetizationMode = self.addChild({'name': 'Magnetization Mode', 'type': 'list',
                                                'values': ['From Start', 'Steady State'], 'value': 'From Start'})
        self.timeMode = self.addChild({'name': 'Time Mode', 'type': 'list', 'values': ['All Points', 'End Points'],
                                       'value': 'All Points'})

        # resolution
        self.pointsResolution = self.addChild({'name': 'Points of Resolution', 'type': 'int', 'value': 128})
        self.timeResolution = self.addChild({'name': 'Time Resolution', 'type': 'float', 'value': 1e-6, 'suffix': 's',
                                             'siPrefix': True})

        # display
        self.show3DAxes = self.addChild({'name': 'Show Axes', 'type': 'bool', 'value': True})
        self.show3DGrid = self.addChild({'name': 'Show Grid', 'type': 'bool', 'value': True})
        self.plot3DGrad = self.addChild({'name': 'Show Gradient Lines', 'type': 'bool', 'value': True})

        # sample
        self.showSample = self.addChild({'name': 'Show Sample', 'type': 'bool', 'value': False})

        # magnet
        self.showMagnet = self.addChild({'name': 'Show Magnet', 'type': 'bool', 'value': False})

        # display
        self.plot3DOffResMag = self.addChild({'name': 'Off Resonance Magnetization', 'type': 'bool', 'value': True})
        self.plot3DOffResPercentage = self.addChild({'name': 'Off Resonance Magnetization Percentage', 'type': 'float',
                                                     'value': 10.0, 'suffix': '%', 'limits': (0, 100)})
        self.plot3DTotalMag = self.addChild({'name': 'Show Total Magnetization', 'type': 'bool', 'value': True})
        self.plot3DTotalMagZero = self.addChild({'name': 'Show Initial Magnetization', 'type': 'bool', 'value': True})
